/**********************************************************BeginFile************
* Copyright:
* (c) 2001 by CONSUL risk management b.v.  All Rights Reserved
*
* File-stamp: <050513 ed 16:14 rtvjratt.c>
*
* Name:
*   rtvjratt.c
*
* Purpose:
*   return the attributes of a journal receiver.
*
* History: 
***********************************************************EndFile*************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <qjournal.h>
#include <qusec.h>

/* #define TRACE */

/* Parameters */
#define QUALIFIED_JOURNAL_NAME "QAUDJRN   QSYS      " 
#define BLANKFIELDNAME "          "
#define BLANKFIELDTIME "             "
#define FIELDSIZENAME 10
#define FIELDSIZETIME 13

/**********************************************************BeginFunction********
* Name:
*   main - Main function
*
* Return values:
*   Name                        Meaning
*   argv[1]                     In:Name of the library of the journal receiver
*   argv[2]                     In:Name of the journal receiver
*   argv[3]                     Out: Name of the previous JR library
*   argv[4]                     Out: Name of the previous JR
*   argv[5]                     Out: Name of the next JR library
*   argv[6]                     Out: Name of the next JR
*   argv[7]                     Out: Attach date and time
*   argv[8]                     Out: Detach date and time 
*
*   Program return value        0: Data successfully fetched
*                               1: Failure
*
* History:
*   011114 0.0.1    HJvT   E-Div:     Created.
***********************************************************EndFunction*********/
main(int   argc,
     char *argv[])
{
  Qjo_Qual_Jrn_Name_t           qualifiedJournalRcvName   = QUALIFIED_JOURNAL_NAME; 
  Qus_EC_t                      errorCode              = {0, 0, ' '};
  Qjo_Format_Name_t             formatName             = QJO_RTV_JRN_RCV_INFO_0100;
  Qjo_RRCV0100_t                receiverVariable;
  int                           error;
  signed long int               sizeOfReceiverVariable = sizeof(receiverVariable);
  int index = 0;

  error = argc != 7 ? 1: 0;
  
  for (index = 1; index <= 2 && !error; index++)
    error = strcmp(argv[index], BLANKFIELDNAME) == 0 ? 2: 0;
  
  /* create qualified Journal receive name from argv[1] + argv[2]*/
  
  if (!error)
  {
    memcpy(qualifiedJournalRcvName, argv[2], FIELDSIZENAME);
    memcpy(qualifiedJournalRcvName + FIELDSIZENAME , argv[1], FIELDSIZENAME);
    QjoRtvJrnReceiverInformation(&receiverVariable,
                                 (signed long int *) &sizeOfReceiverVariable,
                                 qualifiedJournalRcvName,
                                 formatName,
                                 &errorCode);
    error = *(errorCode.Exception_Id) != ' '?2:0;
  }
  
  if (!error)
  {
    /* library of previous receiver */
    memcpy(argv[3], receiverVariable.Prev_Jrn_Rcv_Lib_Name, FIELDSIZENAME);
      
    /* name of previous receiver */
    memcpy(argv[4], receiverVariable.Prev_Jrn_Rcv_Name, FIELDSIZENAME);

    /* library of next receiver */
    memcpy(argv[5], receiverVariable.Next_Jrn_Rcv_Lib_Name, FIELDSIZENAME);

    /* name of next receiver */
    memcpy(argv[6], receiverVariable.Next_Jrn_Rcv_Name, FIELDSIZENAME);

    /* attach date and time */
    memcpy(argv[7], receiverVariable.Attach_Date_Time, FIELDSIZETIME);

    /* detach date and time */
    memcpy(argv[8], receiverVariable.Detach_Date_Time, FIELDSIZETIME);
 
#ifdef TRACE
    for (index=0; index <= 8; index++)
      printf("argv[%d]: <%13s>\n", index, argv[index]);
#endif
  }

  if (error)
  {
    /* Could not retrieve the information */
    for (index = 3; index <= 6 && error > 1; index++)
      memcpy(argv[index], BLANKFIELDNAME, FIELDSIZENAME);
    for (index = 7; index <= 8 && error > 1; index++)
      memcpy(argv[index], BLANKFIELDTIME, FIELDSIZETIME);

#ifdef TRACE
    printf("QjoRtvJrnReceiverInformation() failed (%d)\n", error);
#endif

  }
  
  return error;
}
