/**********************************************************BeginFile************
* Copyright:
* (c) 2001 by CONSUL risk management b.v.  All Rights Reserved
*
* File-stamp: <011128 henk-jan 13:37 rtvjrnrcv.c>
*
* Name:
*   rtvjrnrcv.c
*
* Purpose: 
*   To define the journal receiver connected to the audit journal
*
* History: 
*   011113 0.0.1    HJvT   E-Div:     Created.
***********************************************************EndFile*************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <qjournal.h>
#include <qusec.h>

/* #define TRACE */

/* Parameters */
#define QUALIFIED_JOURNAL_NAME "QAUDJRN   QSYS      " 


/**********************************************************BeginFunction********
* Name:
*   main - Main function
*
* Return values:
*   Name                        Meaning
*   argv[1]                     Name of the library of the journal receiver
*   argv[2]                     Name of the journal receiver
*   Program return value        0: Data successfully fetched
*                               1: Failure
*
* History:
*   011114 0.0.1    HJvT   E-Div:     Created.
***********************************************************EndFunction*********/
main(int   argc,
     char *argv[])
{
  Qjo_Qual_Jrn_Name_t           qualifiedJournalName   = QUALIFIED_JOURNAL_NAME; 
  Qus_EC_t                      errorCode              = {0, 0, ' '};
  Qjo_Format_Name_t             formatName             = QJO_RTV_JRN_INFO_0100;
  Qjo_JN_Jrn_Info_Retrieve_t    journalInformation     = {0};
  Qjo_RJRN0100_t                receiverVariable;
  int                           error;
  signed long int               sizeOfReceiverVariable = sizeof(receiverVariable);

  error = 0;

  QjoRetrieveJournalInformation(&receiverVariable,
                                (signed long int *) &sizeOfReceiverVariable,
                                qualifiedJournalName,
                                formatName,
                                &journalInformation,
                                &errorCode);
  
  if (*(errorCode.Exception_Id) != ' ')
  {
    /* Could not retrieve the information */
    memcpy(argv[1], "            ", 10);
    memcpy(argv[2], "            ", 10);
#ifdef TRACE
    printf("QjoRetrieveJournalInformation() failed\n");
#endif

    error = 1;
  }
  
  
  if (0 == error)
  {
    /* Journal Receiver Library name */
    memcpy(argv[1], receiverVariable.Att_Jrn_Rcv_Lib_Name, 10);
      
    /* Journal Receiver name */
    memcpy(argv[2], receiverVariable.Att_Jrn_Rcv_Name, 10);
    
#ifdef TRACE
      printf("Lib: <%10s>, Name: <%10s>\n",
             receiverVariable.Att_Jrn_Rcv_Lib_Name,
             receiverVariable.Att_Jrn_Rcv_Name);
#endif
  }
    
  return error;
}
