/**********************************************************BeginFile************
* Copyright:
* (c) 2001 by CONSUL risk management b.v.  All Rights Reserved
*
* File-stamp: <020219 Henk-Jan 17:09 toUTF8.c>
*
* Name:
*   toUTF8.c
*
* Purpose: 
*   To convert a DSPJRN output file to UTF8 format
*
* History: 
*   011115 0.0.1     HJvT   WE109005:  Created.
***********************************************************EndFile*************/
#include <recio.h>
#include <stddef.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <errno.h>
#include <ctype.h>

#include <baselib.h>
#include <crm.h>
#include <crmbase.h>
#include <utf8.h>

#include <qjournal.h>
#include <qusec.h>
/* 020218 0.0.10 HJvT UE112013: inserted the following line: */
#include <localmsg.h>

/* Parameters */
#define DEFAULTBUFFERSIZE 32768

#define LOGDIR         "../log"
#define LOGFILENAME    LOGDIR"/toUTF8.log"

#define TRACE
#define DEBUG

#define INFO_MESSAGE(msg)          CRMWRITELOG(CRM_AUD_DEVELOPER | CRM_AUD_OPERATOR | CRM_AUD_AUDITOR, \
                                               CRM_SVR_INFO,                                           \
                                               msg)
  
#define FATAL_ERROR_MESSAGE(msg)   CRMWRITELOG(CRM_AUD_DEVELOPER | CRM_AUD_OPERATOR | CRM_AUD_AUDITOR, \
                                               CRM_SVR_FATAL_ERROR,                                    \
                                               msg)

#define SEVERE_ERROR_MESSAGE(msg)  CRMWRITELOG(CRM_AUD_DEVELOPER | CRM_AUD_OPERATOR | CRM_AUD_AUDITOR, \
                                               CRM_SVR_SEVERE_ERROR,                                   \
                                               msg)

#define ERROR_MESSAGE(msg)         CRMWRITELOG(CRM_AUD_DEVELOPER | CRM_AUD_OPERATOR | CRM_AUD_AUDITOR, \
                                               CRM_SVR_ERROR,                                   \
                                               msg)

/* Global variables */
static Log *loghandle = NULL;

/* Prototypes of local functions */
char       *explainErrno();                 /* Explain the value of errno */


/**********************************************************BeginFunction********
* Name:
*   explainErrno - Explain the errno value
*
* History:
*   011122 0.0.1    HJvT   WE109005:     Created.
***********************************************************EndFunction*********/
char *explainErrno()
{
  char *result;
  char  errnoString[100];
  int   errnum;

  errnum = errno;
  errno  = 0;
  result = strerror(errnum);
  if (0 != errno)
    result = "<Unable to retrieve system message>";

  return result;
}


/**********************************************************BeginFunction********
* Name:
*   main - Main function
*
* Parameters: 
*   Name     Valid range  Usage
*   argv[1]  char[22]     Name of file to convert (source physical file in
*                         current library), format: [<library>/]<file>
*   argv[2]  char[256]    Name to use for output file (IFS file path/name)
*
* History:
*   011115 0.0.1    HJvT   WE109005:  Created.
***********************************************************EndFunction*********/
main(int   argc,
     char *argv[])
{
  char            currentLibrary[11];
  int             error;
  _RFILE         *eventLog;
  CRMBOOLEAN      help;
  void           *initparms[2]; /* For CRMLogOpen() */
  char            inputFileName[22];
  char           *logFileName;
  FILE           *outputFile;
  char            outputFileName[100];
  int             phase;

  phase = 1;
  error = 0;

/* 020218 0.0.10 HJvT WE109005: deleted the following lines:  */
/*
#ifdef TRACE
  printf("%s: Input file: %s, Output file: %s\n",
  .       argv[0],
  .       argv[1],
  .       argv[2]);
#endif
  .
  .strncpy(inputFileName,  argv[1], sizeof(inputFileName)  - 1);
  .strncpy(outputFileName, argv[2], sizeof(outputFileName) - 1);
  .inputFileName[sizeof(inputFileName)]   = '\0';
  .outputFileName[sizeof(outputFileName)] = '\0';
  . 
  .!* Strip off spaces at the end of outputFileName *!
  .{
  .  char *endOfName;
  .
  .  endOfName = strchr(outputFileName, ' ');
  .  if (NULL != endOfName)
  .    *endOfName = '\0';
  .}
*/
  
  if (0 == error)
  {
    phase++;

    logFileName = LOGFILENAME;

    if (CRM_RC_OK != CRMLogInit())
    {
      fprintf(stderr, "%s: Failed to initiate logging\n",
              argv[0]);
      error = phase;
    }
  }
    
  if (0 == error)
  {
    phase++;

    initparms[0] = (void *) logFileName;
    initparms[1] = (void *) 2000;

    if (CRMLogOpen(&loghandle,
                   logFileName,
                   2,
                   initparms,
                   OpenBinLog,
                   WriteToBinLog,
                   CloseBinLog) != CRM_RC_OK)
    {
      fprintf(stderr, "%s: Failed to open log file: %s\n",
              argv[0],
              logFileName);
      error = phase;
    }
  }

/* 020218 0.0.10 HJvT WE109005: inserted the following lines: */
  if (0 == error)
  {
    phase++;

    if (3 != argc)
    {
      error = phase;

      FATAL_ERROR_MESSAGE(LOG_OS400_TOUTF8_USAGE(argv[0]));
    }
  }
  
  if (0 == error)
  {
    phase++;

#ifdef TRACE
    printf("%s: Input file: %s, Output file: %s\n",
           argv[0],
           argv[1],
           argv[2]);
#endif

    strncpy(inputFileName,  argv[1], sizeof(inputFileName)  - 1);
    strncpy(outputFileName, argv[2], sizeof(outputFileName) - 1);
    inputFileName[sizeof(inputFileName)]   = '\0';
    outputFileName[sizeof(outputFileName)] = '\0';
  
    /* Strip off spaces at the end of outputFileName */
    {
      char *endOfName;

      endOfName = strchr(outputFileName, ' ');
      if (NULL != endOfName)
        *endOfName = '\0';
    }
  }
/* End mod 020218 */

  /* Open the input file */
  if (0 == error)
  {
    phase++;
    
    CRMTrace("%s: Opening input file <%s>",
             argv[0],
             inputFileName);
    eventLog =  _Ropen(inputFileName, "rr, arrseq=Y");
    if (NULL == eventLog)
    {
      error = phase;
      FATAL_ERROR_MESSAGE(LOG_OS400_CANNOT_OPEN_INPUT_FILE(argv[0],
                                                           inputFileName,
                                                           explainErrno()));
    }
  }
    
  /* Open the output file */
  if (0 == error)
  {
    phase++;
    
    CRMTrace("%s: Opening output file <%s>",
             argv[0],
             outputFileName);
    outputFile = fopen(outputFileName, "w");
    if (outputFile == NULL)
    {
      error = phase;
      FATAL_ERROR_MESSAGE(LOG_OS400_CANNOT_OPEN_OUTPUT_FILE(argv[0],
                                                            outputFileName,
                                                            explainErrno()));
    }
  }
  
  /* Convert the input file */
  if (0 == error)
  {
    int        index;
    int        length;
    char       lengthString[6];
    CRMBYTE    outputLine[DEFAULTBUFFERSIZE];
    char       record[DEFAULTBUFFERSIZE];
    CRMUINT32  size;
      
    phase++;
      
    /*
      Read all records of the journal,
      convert them to "UTF-8"
      and write them in the output file
    */
    for (; 0 == error;)
    {
      errno = 0;
      
      _Rreadn(eventLog, record, DEFAULTBUFFERSIZE, __DFT);
      if (0 != errno)
      {
        FATAL_ERROR_MESSAGE(LOG_OS400_CANNOT_READ_INPUT_FILE(argv[0],
                                                             inputFileName,
                                                             explainErrno()));
        
        error = phase;
      }

      if (0 == error)
      {
        if (eventLog->riofb.num_bytes == EOF)
          break; /* Stop when everything is read */

        /*
          Convert the line to UTF8 and write it in the output file
        */
        /* Find out what the record length is */
        strncpy(lengthString, record, 5);
        lengthString[5] = '\0';
        length          = atoi(lengthString);

        /* Convert non-printable characters to question marks */
        for (index = 0; 
             index < length; 
             index++)
        {
          if (0 == isprint(record[index]))
            record[index] = '?';
        }

        /* Append a null character */
        record[length] = '\0';
        
        /* Append a new-line character */
        strcat(record, "\n");
        length = strlen(record);
        
        /* Convert to UTF8 */
        if (0 != ASC8Encode(record,
                            length,
                            outputLine,
                            &size))
        {
          ERROR_MESSAGE(LOG_OS400_CANNOT_CONVERT_RECORD(argv[0],
                                                        record));
          /* error = phase; // We don't want to abort here */
        }

        if (size >= sizeof(outputLine))
        {
          ERROR_MESSAGE(LOG_OS400_RECORD_TOO_LONG(argv[0],
                                                  record));
          /* error = phase; // We don't want to abort here */
        }
      }

      /* Write to the output file */
      if (0 == error)
      {
        /* Append a null character */
        outputLine[size] = '\0';

        errno = 0;
        fprintf(outputFile,
                "%s",
                outputLine);
        switch (errno)
        {
          case 0:
            /* All is well (?) */
            break;
      
          case ENOSPC:
            error = phase;
            FATAL_ERROR_MESSAGE(LOG_OS400_DISK_FULL(argv[0],
                                                    outputFileName));
            break;
            
          default:
            error = phase;
            FATAL_ERROR_MESSAGE(LOG_OS400_CANNOT_WRITE_OUTPUT_FILE(argv[0],
                                                                   outputFileName,
                                                                   explainErrno()));
        }
      }      
    } /* End for() */
  } 
    
  if (NULL != loghandle)
  {
    INFO_MESSAGE(LOG_OS400_FINISHED(argv[0]));
    
    CRMLogClose(loghandle,
                0,
                NULL);
  }
    
  CRMLogExit();
  
  return error;
}
