////////////////////////////////////////////////////////////////////////////////////////////////
//
// Begin of file getSysScanLog.cpp
//
////////////////////////////////////////////////////////////////////////////////////////////////
#define UNICODE
#define _UNICODE

#include <windows.h>
#include <tchar.h>
#include <stdio.h>
#include "getSysScanLog.h"

////////////////////////////////////////////////////////////////////////////////////////////////
//
// Entry point for application
//
// Arguments: <Temp file> <dummy> <dummy> <dummy> <path SysScan Console> <Hosts File>
//						TemporayFile1												Option1                Option2  
////////////////////////////////////////////////////////////////////////////////////////////////

int wmain(int argc, TCHAR* argv[])
{
	TCHAR dirToConsole[1024];
	int i;

	if(argc<=3)
	{
		return 0;
	}

	logFile=CreateFile(_T("..\\log\\SysScan.log"),GENERIC_WRITE,0,NULL,CREATE_ALWAYS,
		FILE_ATTRIBUTE_NORMAL,NULL);

	LogMessage(_T("Command Line: "));
	for (i=0;i<argc;i++)
	{
		LogMessage(_T("\""));
		LogMessage(argv[i]);
		LogMessage(_T("\""));
		LogMessage(_T(" "));
	}
	LogMessage(_T("\n"));

	_tcscpy(dirToConsole,argv[PATH_TO_CON]);
	_tcscpy(szHostFile,argv[HOST_FILE]);

	ClearFiles(dirToConsole);

	if(!CreateInput(dirToConsole,szHostFile))
	{
		LogMessage(_T("Error: cannot create temporary file\n"));
		return 1;
	}

	if(!RetrieveReports(dirToConsole))
	{
		LogMessage(_T("Error: main: cannot retrieve reports files\n"));
		CloseHandle(logFile);
		return 1;
	}

	if(!ReadReports(dirToConsole))
	{
		LogMessage(_T("Error: main: cannot read reports files\n"));
		free(cCSVDet);
		free(cCSVSum);
		CloseHandle(logFile);
		return 1;
	}

	if(!SaveReports(argv[TEMP_FILE]))
	{
		LogMessage(_T("Error: main: cannot save output file\n"));
		free(cCSVDet);
		free(cCSVSum);
		CloseHandle(logFile);
		return 1;
	}

	ClearFiles(dirToConsole);
	
	LogMessage(_T("Success"));
	CloseHandle(logFile);

	free(cCSVDet);
	free(cCSVSum);
	

	return 0;
}

////////////////////////////////////////////////////////////////////////////////////////////////
//
// Function:	ClearFiles
//
// Purpose:		Deletes unnessesary files after program working
// Arguments:	LPTSTR path - path to ISS System Scanner Console
//
////////////////////////////////////////////////////////////////////////////////////////////////
void ClearFiles(LPTSTR path)
{
	TCHAR path2[1024];
	TCHAR path3[1024];

	wsprintf(path2,_T("%s\\reports\\deviation\\ForConsul\\html\\*.*"),path);

	WIN32_FIND_DATA FindData;
	HANDLE hFind;
	BOOL res;
	DWORD dwError;

	hFind = FindFirstFile(path2,&FindData);

    if(hFind==INVALID_HANDLE_VALUE)
	{
		dwError=GetLastError();
	}

	while(hFind!=INVALID_HANDLE_VALUE)
	{
		
		if(_tcscmp(FindData.cFileName,_T("."))==0)
		{
			FindNextFile(hFind,&FindData);
			if(_tcscmp(FindData.cFileName,_T(".."))==0)
			{
				FindNextFile(hFind,&FindData);
			}
		}
		FindClose(hFind);
		wsprintf(path3,_T("%s\\reports\\deviation\\ForConsul\\html\\%s"),path,FindData.cFileName);
		res=DeleteFile(path3);
		if(!res)
		{
			dwError=GetLastError();
			break;
		}
		
		hFind = FindFirstFile(path2,&FindData);
	}	// while

	wsprintf(path2,_T("%s\\reports\\deviation\\ForConsul\\html"),path);
	RemoveDirectory(path2);

	wsprintf(path2,_T("%s\\reports\\deviation\\ForConsul\\csv\\*.*"),path);

	hFind = FindFirstFile(path2,&FindData);
	
	
	while(hFind!=INVALID_HANDLE_VALUE)
	{
		if(_tcscmp(FindData.cFileName,_T("."))==0)
		{
			FindNextFile(hFind,&FindData);
			if(_tcscmp(FindData.cFileName,_T(".."))==0)
			{
				FindNextFile(hFind,&FindData);
			}
		}
		FindClose(hFind);
		wsprintf(path3,_T("%s\\reports\\deviation\\ForConsul\\csv\\%s"),path,FindData.cFileName);
		res=DeleteFile(path3);
		if(!res)
		{
			dwError=GetLastError();
			break;
		}
		
		hFind = FindFirstFile(path2,&FindData);
	}	//while

	wsprintf(path2,_T("%s\\reports\\deviation\\ForConsul\\csv"),path);
	RemoveDirectory(path2);

	wsprintf(path2,_T("%s\\reports\\deviation\\ForConsul"),path);
	RemoveDirectory(path2);
}

////////////////////////////////////////////////////////////////////////////////////////////////
//
// Function:	RetrieveReports.
//
// Purpose:		Retrieves reports from ISS System Scanner Agents into report\deviaton dir of 
//				System Scanner Console.
// Arguments:	LPTSTR path - path to ISS System Scanner Console
//
// Additional info: none.
//
////////////////////////////////////////////////////////////////////////////////////////////////
BOOL RetrieveReports(LPTSTR path)
{
	TCHAR execPath[1024];
    STARTUPINFO si;
    PROCESS_INFORMATION pi;

    ZeroMemory( &si, sizeof(si) );
    si.cb = sizeof(si);
    ZeroMemory( &pi, sizeof(pi) );

//-------- Retriving results from agent --------------------------------------------------------

	TCHAR curDir[1024];
	GetCurrentDirectory(1024,curDir);
	
	wsprintf(execPath,
		_T("%s\\bin\\smnetsh.exe \"%s\\scripts\\retrieve_results\" \"%s\\%s\""),
		path,path,curDir,szHostFile);

    if(!CreateProcess(NULL, execPath, NULL, NULL, FALSE, CREATE_NO_WINDOW, NULL, NULL, &si, &pi)) 
    {
		LogMessage(_T(" Error: RetrieveReports: cannot retrieve results from agent\n"));
        return FALSE;
    }

    WaitForSingleObject( pi.hProcess, INFINITE );

    CloseHandle( pi.hProcess );
    CloseHandle( pi.hThread );

//-------- Retriving CSV reports ---------------------------------------------------------------

	wsprintf(execPath,
		_T("\"%s\\bin\\smnetsh\" \"%s\\scripts\\genCSVreport\" ForConsul \"%s\\input.txt\""),
		path,path,curDir);

	
    if(!CreateProcess(NULL, execPath, NULL, NULL, FALSE, CREATE_NO_WINDOW, NULL, NULL, &si, &pi)) 
    {
		LogMessage(_T("Error: RetrieveReports: cannot collect CSV reports\n"));
        return FALSE;
    }

    WaitForSingleObject( pi.hProcess, INFINITE );

    CloseHandle( pi.hProcess );
    CloseHandle( pi.hThread );

//-------- Retriving HTML reports --------------------------------------------------------------

	wsprintf(execPath,
		_T("\"%s\\bin\\smnetsh\" \"%s\\scripts\\genreport\" ForConsul \"%s\\input.txt\""),
		path,path,curDir);

    ZeroMemory( &si, sizeof(si) );
    si.cb = sizeof(si);
    ZeroMemory( &pi, sizeof(pi) );

    if(!CreateProcess(NULL, execPath, NULL, NULL, FALSE, CREATE_NO_WINDOW, NULL, NULL, &si, &pi)) 
    {
		LogMessage(_T("Error: RetrieveReports: cannot collect HTML reports\n"));
        return FALSE;
    }

    WaitForSingleObject( pi.hProcess, INFINITE );

    CloseHandle( pi.hProcess );
    CloseHandle( pi.hThread );

//-------- Deleting temporary files ------------------------------------------------------------

	DeleteFile(_T("input.txt"));

	return TRUE;
}

////////////////////////////////////////////////////////////////////////////////////////////////
//
// Function:	LogMessage
//
// Purpose:		Logs specified message into logfile
// Arguments:	LPTSTR message - message to log.
//
// Additional info:	none
//
////////////////////////////////////////////////////////////////////////////////////////////////
void LogMessage(LPTSTR message)
{
	char message2[1024];
	DWORD dwWritten;

	CharToOem(message,message2);
	if(logFile!=INVALID_HANDLE_VALUE)
		WriteFile(logFile,message2,strlen(message2)*sizeof(char),&dwWritten,NULL);
}

////////////////////////////////////////////////////////////////////////////////////////////////
//
// Function:	ReadReports
//
// Purpose:		Reads time from HTML report and reads all of CSV reports (summary and detailed).
// Arguments:	LPTSTR path - path to System Scanner Console.
//
// Additional info:	none
//
////////////////////////////////////////////////////////////////////////////////////////////////
BOOL ReadReports(LPTSTR path)
{
	char  cHTML[1024];
	TCHAR path2[1024];

	HANDLE hHTML;
	HANDLE hCSVDet;
	HANDLE hCSVSum;

//---------------- Read time from html report --------------------------------------------------

	WIN32_FIND_DATA FindData;
	ZeroMemory(&FindData,sizeof(FindData));
	
	wsprintf(path2,_T("%s\\reports\\deviation\\ForConsul\\html\\%s"),path,_T("*.html"));
	
	HANDLE hFind=FindFirstFile(path2,&FindData);
	FindClose(hFind);

	wsprintf(path2,_T("%s\\reports\\deviation\\ForConsul\\html\\%s"),path,FindData.cFileName);

	hHTML=CreateFile(path2,GENERIC_READ,0,NULL,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL,NULL);
	if(hHTML==INVALID_HANDLE_VALUE)
	{
		DWORD dwError=GetLastError();
		TCHAR Message[1024];
		wsprintf(Message,_T("Error: ReadReports: Cannot open html report file %s. Error number %d\n"),
			FindData.cFileName,dwError);
		LogMessage(Message);
		return FALSE;
	}
	DWORD dwReaded;
	if(!ReadFile(hHTML,cHTML,1024*sizeof(char),&dwReaded,NULL))
	{
		DWORD dwError=GetLastError();
		TCHAR Message[1024];
		wsprintf(Message,_T("Error: ReadReports: Cannot read html report file %s. Error number %d\n"),
			FindData.cFileName,dwError);
		LogMessage(Message);
		CloseHandle(hHTML);
		return FALSE;
	}
	if(dwReaded!=(1024*sizeof(char)))
	{
		TCHAR Message[1024];
		wsprintf(Message,_T("Error: ReadReports: Cannot read html report file %s.\n"),
			FindData.cFileName);
		LogMessage(Message);
		CloseHandle(hHTML);
		return FALSE;
	}
	cHTML[1023]='\0';

	char* time=strstr(cHTML,"Started:");
	time+=(9*sizeof(char));
	strncpy(szTime,time,19);
	szTime[19]='\0';

	CloseHandle(hHTML);
	
//-------------------- Reading CSV Summary report -----------------------------------------------

	ZeroMemory(&FindData,sizeof(FindData));

	wsprintf(path2,_T("%s\\reports\\deviation\\ForConsul\\csv\\%s"),path,_T("*_sum.txt"));

	hFind=FindFirstFile(path2,&FindData);
	FindClose(hFind);

	wsprintf(path2,_T("%s\\reports\\deviation\\ForConsul\\csv\\%s"),path,FindData.cFileName);

	hCSVSum=CreateFile(path2,GENERIC_READ,0,NULL,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL,NULL);
	if(hCSVSum==INVALID_HANDLE_VALUE)
	{
		DWORD dwError=GetLastError();
		TCHAR Message[1024];
		wsprintf(Message,_T("Error: Cannot open csv summary report file %s. Error number %d\n"),
			FindData.cFileName,dwError);
		LogMessage(Message);
		return FALSE;
	}

	DWORD FileSize=GetFileSize(hCSVSum,NULL);
	if(FileSize==INVALID_FILE_SIZE)
	{
		DWORD dwError=GetLastError();
		TCHAR Message[1024];
		wsprintf(Message,
			_T("Error: Cannot obtain size of csv summary report file %s. Error number %d\n"),
			FindData.cFileName,dwError);
		LogMessage(Message);
		CloseHandle(hCSVSum);
		return FALSE;
	}
	
	cCSVSum=(char*)malloc(FileSize+1);
	if(!ReadFile(hCSVSum,cCSVSum,FileSize,&dwReaded,NULL))
	{
		DWORD dwError=GetLastError();
		TCHAR Message[1024];
		wsprintf(Message,_T("Error: ReadReports: Cannot read CSV summary report file %s. Error number %d\n"),
			FindData.cFileName,dwError);
		LogMessage(Message);
		CloseHandle(hCSVSum);
		return FALSE;
	}
	if(dwReaded!=FileSize)
	{
		TCHAR Message[1024];
		wsprintf(Message,_T("Error: ReadReports: Cannot read CSV summary report file %s.\n"),
			FindData.cFileName);
		LogMessage(Message);
		CloseHandle(hCSVSum);
		return FALSE;
	}
	cCSVSum[FileSize]='\0';

	CloseHandle(hCSVSum);

//-------------------- Reading CSV Detail report -----------------------------------------------

	ZeroMemory(&FindData,sizeof(FindData));

	wsprintf(path2,_T("%s\\reports\\deviation\\ForConsul\\csv\\%s"),path,_T("*_det.txt"));

	hFind=FindFirstFile(path2,&FindData);
	FindClose(hFind);

	wsprintf(path2,_T("%s\\reports\\deviation\\ForConsul\\csv\\%s"),path,FindData.cFileName);

	hCSVDet=CreateFile(path2,GENERIC_READ,0,NULL,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL,NULL);
	if(hCSVDet==INVALID_HANDLE_VALUE)
	{
		DWORD dwError=GetLastError();
		TCHAR Message[1024];
		wsprintf(Message,_T("Error: Cannot open csv detail report file %s. Error number %d\n"),
			FindData.cFileName,dwError);
		LogMessage(Message);
		return FALSE;
	}

	FileSize=GetFileSize(hCSVDet,NULL);
	if(FileSize==INVALID_FILE_SIZE)
	{
		DWORD dwError=GetLastError();
		TCHAR Message[1024];
		wsprintf(Message,
			_T("Error: Cannot obtain size of csv detail report file %s. Error number %d\n"),
			FindData.cFileName,dwError);
		LogMessage(Message);
		CloseHandle(hCSVDet);
		return FALSE;
	}
	
	cCSVDet=(char*)malloc(FileSize+1);
	if(!ReadFile(hCSVDet,cCSVDet,FileSize,&dwReaded,NULL))
	{
		DWORD dwError=GetLastError();
		TCHAR Message[1024];
		wsprintf(Message,_T("Error: ReadReports: Cannot read CSV detail report file %s. Error number %d\n"),
			FindData.cFileName,dwError);
		LogMessage(Message);
		CloseHandle(hCSVDet);
		return FALSE;
	}
	if(dwReaded!=FileSize)
	{
		TCHAR Message[1024];
		wsprintf(Message,_T("Error: ReadReports: Cannot read CSV detail report file %s.\n"),
			FindData.cFileName);
		LogMessage(Message);
		CloseHandle(hCSVDet);
		return FALSE;
	}
	cCSVDet[FileSize]='\0';
	CloseHandle(hCSVDet);
	return TRUE;
}

////////////////////////////////////////////////////////////////////////////////////////////////
//
// Function:	SaveReports
//
// Purpose:		Parses and saves parsed reports into temporary file
// Arguments:	LPTSTR szTempFileName - Temprary file name to which save reports
//
// Additional info:	none
//
////////////////////////////////////////////////////////////////////////////////////////////////
BOOL SaveReports(LPTSTR szTempFileName)
{
	HANDLE hTempFile = CreateFile(szTempFileName,GENERIC_WRITE,0,NULL,CREATE_ALWAYS,
							FILE_ATTRIBUTE_NORMAL,NULL);

	if(hTempFile==INVALID_HANDLE_VALUE)
	{
		LogMessage(_T("Error: SaveReports: cannot create output file\n"));
		return FALSE;
	}
	
	char *curPosSum;
	char *begCPosSum;
	char *curPosDet;
	char *begCPosDet;
	
	begCPosSum=cCSVSum;
	begCPosDet=cCSVDet;

	curPosSum=strstr(begCPosSum,"\r\n");
	curPosDet=strstr(begCPosDet,"\r\n");

	int i;
	while(curPosSum!=NULL)
	{
		SaveData data;
		ParseSumString(begCPosSum,&data);

		BOOL first;
		BOOL PrInDet;
		first=TRUE;
		PrInDet=TRUE;
		int numEvents;
		char *temp;
		char *temp2;
		char *cDetVName=NULL;
		char *cDetVName2=NULL;
		temp=begCPosDet;
		temp2=curPosDet;
		numEvents=0;

    if(data.Vuln>=1)
		{
			cDetVName=GetDetVName(temp);
			cDetVName2=GetDetVName(temp);
  		if((cDetVName!=NULL)&&(strcmp(cDetVName,data.VulName)==0)/*&&(curPosDet!=NULL)*/)
			{
				while((temp!=NULL)&&(strcmp(cDetVName,cDetVName2)==0))
				{
					numEvents++;
					temp=temp2+2;
					temp2=strstr(temp,"\r\n");
					if(temp2==NULL)
						temp=NULL;
					free(cDetVName2);
					cDetVName2=GetDetVName(temp);
				}
			}
			else
			{
				PrInDet=FALSE;
			}
			free(cDetVName);
			free(cDetVName2);
		}
		int k=-1;
		for(i=0;i<numEvents;i++)
		{
			
			if(numEvents!=1)
			{
				if(k!=atoi((curPosDet+2)))
					first=TRUE;
				k=atoi(begCPosDet);
				
				if((k==atoi((curPosDet+2)))&&(first))
				{
					begCPosDet=curPosDet+2;
					curPosDet=strstr(begCPosDet,"\r\n");
					i++;
					first=FALSE;
				}
			}

			ParseDetString(begCPosDet,&data);
			WriteDataToFile(hTempFile,data);
			begCPosDet=curPosDet+2;
			curPosDet=strstr(begCPosDet,"\r\n");
			free(data.ObjName);
		}
		if((!PrInDet)&&(data.Vuln>=1))
		{
			data.ObjName=(char*)malloc(strlen("Unknown")+sizeof(char));
			strcpy(data.ObjName,"Unknown");
			data.ObjName[strlen("Unknown")]='\0';

			WriteDataToFile(hTempFile,data);
			free(data.ObjName);
		}

		free(data.Description);
		free(data.host);
		free(data.VulName);
		
		begCPosSum=curPosSum+2;
		curPosSum=strstr(begCPosSum,"\r\n");
	}
	CloseHandle(hTempFile);
	return TRUE;
}

////////////////////////////////////////////////////////////////////////////////////////////////
//
// Function:	ParseSumString
//
// Purpose:		Parses string from CSV summary report and fills structure
// Arguments:	char* szParse - string to parse, must ends with "\r\n" characters
//				LPSaveData data - structure to fill. All char* members must be not allocated.
//									Callig function must frees this pointers by self whith 
//									CRT free() function.
//
// Additional info:	none
//
////////////////////////////////////////////////////////////////////////////////////////////////
void ParseSumString(char* szParse, LPSaveData data)
{
	char* Pos1;
	char* Pos2;

	Pos1=szParse;
	Pos2=strstr(Pos1,"\t");

	data->host=(char*)malloc(Pos2-Pos1+sizeof(char));
	strncpy(data->host,Pos1,Pos2-Pos1);
	data->host[Pos2-Pos1]='\0';

	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\t");

	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\t");

	data->VulName=(char*)malloc(Pos2-Pos1+sizeof(char));
	strncpy(data->VulName,Pos1,Pos2-Pos1);
	data->VulName[Pos2-Pos1]='\0';

	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\t");

	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\t");
	
	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\t");

	data->Vuln=atoi(Pos1);

	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\t");

	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\r\n");

	data->Description=(char*)malloc(Pos2-Pos1+sizeof(char));
	strncpy(data->Description,Pos1,Pos2-Pos1);
	data->Description[Pos2-Pos1]='\0';
}

////////////////////////////////////////////////////////////////////////////////////////////////
//
// Function:	WriteDataToFile
//
// Purpose:		Writes data from SaveData structure to specified file
// Arguments:	HANDLE hFile - file to write
//				SaveData data - data to write
//
// Additional info:	none
//
////////////////////////////////////////////////////////////////////////////////////////////////
BOOL WriteDataToFile(HANDLE hFile,SaveData data)
{
	DWORD dwWritten;
	WriteFile(hFile,"\"",strlen("\""),&dwWritten,NULL);

	WriteFile(hFile,szTime,strlen(szTime),&dwWritten,NULL);

	WriteFile(hFile,"\"",strlen("\""),&dwWritten,NULL);
	WriteFile(hFile,"\t",strlen("\t"),&dwWritten,NULL);

	WriteFile(hFile,data.host,strlen(data.host),&dwWritten,NULL);

	WriteFile(hFile,"\t",strlen("\t"),&dwWritten,NULL);

	WriteFile(hFile,data.VulName,strlen(data.VulName),&dwWritten,NULL);

	WriteFile(hFile,"\t",strlen("\t"),&dwWritten,NULL);
	WriteFile(hFile,"\"",strlen("\""),&dwWritten,NULL);

	WriteFile(hFile,data.ObjName,strlen(data.ObjName),&dwWritten,NULL);

	WriteFile(hFile,"\"",strlen("\""),&dwWritten,NULL);
	WriteFile(hFile,"\t",strlen("\t"),&dwWritten,NULL);
	WriteFile(hFile,"\"",strlen("\""),&dwWritten,NULL);

	WriteFile(hFile,data.Description,strlen(data.Description),&dwWritten,NULL);

	WriteFile(hFile,"\"",strlen("\""),&dwWritten,NULL);
	WriteFile(hFile,"\n",strlen("\n"),&dwWritten,NULL);

	return TRUE;
}

////////////////////////////////////////////////////////////////////////////////////////////////
//
// Function:	ParseDetString
//
// Purpose:		Parses string from CSV detailed report and fills structure
// Arguments:	char* szParse - string to parse, must ends with "\r\n" characters
//				LPSaveData data - structure to fill. All char* members must be not allocated.
//									Callig function must frees this pointers by self whith 
//									CRT free() function.
//
// Additional info:	Development in progress
//
////////////////////////////////////////////////////////////////////////////////////////////////
void ParseDetString(char* szParse, LPSaveData data)
{
	char* Pos1;
	char* Pos2;

//  if((szParse==NULL)||(strcmp(szParse,"")==0))

	Pos1=szParse;
	Pos2=strstr(Pos1,"\t");

	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\t");

	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\t");

	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\t");

	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\t");
	
	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\t");

	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\r\n");

	data->ObjName=(char*)malloc(Pos2-Pos1+sizeof(char));
	strncpy(data->ObjName,Pos1,Pos2-Pos1);
	data->ObjName[Pos2-Pos1]='\0';
}


char* GetDetVName(char* szParse)
{
	char* Pos1;
	char* Pos2;
	char* data;

	if((szParse==NULL)||(strcmp(szParse,"")==0))
		return NULL;

	Pos1=szParse;
	Pos2=strstr(Pos1,"\t");

	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\t");

	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\t");

	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\t");

	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\t");
	
	Pos2++;
	Pos1=Pos2;
	Pos2=strstr(Pos1,"\t");

	data=(char*)malloc(Pos2-Pos1+sizeof(char));
	strncpy(data,Pos1,Pos2-Pos1);
	data[Pos2-Pos1]='\0';
	return data;
}

BOOL CreateInput(TCHAR* path, TCHAR* hosts)
{
	HANDLE inpFile = CreateFile(_T("input.txt"),GENERIC_WRITE,0,NULL,
		CREATE_ALWAYS,FILE_ATTRIBUTE_NORMAL,NULL);

	if(inpFile==INVALID_HANDLE_VALUE)
	{
		LogMessage(_T("Error: RetieveReports: Cannot create temporary file\n"));
		return FALSE;
	}

	FILE* fp=_tfopen(hosts,_T("r"));
	int res;
	char szHost[1024];
	char szSess[1024];
	char buffer[1024];
	char buffer2[1024];
	DWORD dwWritten;

	do
	{
		res=fscanf(fp,"%s %s",&szHost,&szSess);
		if(res!=EOF)
		{
			CharToOem(path,buffer);
			sprintf(buffer2,"%s\\results\\%s\\deviation\\%s\n",buffer,szHost,szSess);
			WriteFile(inpFile,buffer2,strlen(buffer2)*sizeof(char),&dwWritten,NULL);
		}

	}
	while(res!=EOF);

	CloseHandle(inpFile);
	fclose(fp);
	return TRUE;
}
////////////////////////////////////////////////////////////////////////////////////////////////
//
// End of file getSysScanLog.cpp
//
////////////////////////////////////////////////////////////////////////////////////////////////